SkillError

Enum SkillError 

#[non_exhaustive]
pub enum SkillError { Io { path: PathBuf, source: Error, }, FileTooLarge { path: PathBuf, limit_bytes: u64, }, AssetsTooLarge { path: PathBuf, total_bytes: u64, limit_bytes: u64, }, InvalidUtf8 { path: PathBuf, source: FromUtf8Error, }, InvalidPackFile { path: PathBuf, reason: String, }, ParseManifest { path: PathBuf, source: Error, }, InvalidManifest(String), Config(String), Verification(String), AlreadyRegistered(String), NotFound(String), }
Skill errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io

File I/O failed.

Fields

path: PathBuf

File path.

source: Error

Source error.



FileTooLarge

File exceeded the configured skill-pack size limit.

Fields

path: PathBuf

File path.

limit_bytes: u64

Maximum accepted size in bytes.



AssetsTooLarge

Aggregate skill-pack assets exceeded the configured size limit.

Fields

path: PathBuf

Asset path being read when the aggregate limit was exceeded.

total_bytes: u64

Bytes read across all assets.

limit_bytes: u64

Maximum accepted aggregate asset size in bytes.



InvalidUtf8

A skill-pack text file is not valid UTF-8.

Fields

path: PathBuf

File path.

source: FromUtf8Error

Source error.



InvalidPackFile

A skill-pack path is not an accepted regular pack file or directory.

Fields

path: PathBuf

File path.

reason: String

Rejection reason.



ParseManifest

YAML parsing failed.

Fields

path: PathBuf

Manifest path.

source: Error

Source error.



InvalidManifest(String)

Manifest is invalid.



Config(String)

Config source resolution or validation failed.



Verification(String)

Verification failed.



AlreadyRegistered(String)

Registry conflict.



NotFound(String)

Skill not found.